package Gimp::Config;

=cut

=head1 NAME

  Gimp::Config - config options found during configure time.

=head1 DESCRIPTION

The Gimp::Config module creates a tied hash %Gimp::Config which contains
all the definitions the configure script and perl deduced from the system
configuration at configure time. You can access these values just like you
access any other values, i.e.  C<$Gimp::Config{KEY}>. Some important keys are:

  IN_GIMP	=> true when gimp-perl was part of the Gimp distribution.
  GIMP		=> the path of the gimp executable
  prefix	=> the installation prefix
  libdir	=> the gimp systemwide libdir
  bindir	=> paths where gimp binaries are installed
  gimpplugindir	=> the gimp plug-in directory (without the /plug-ins-suffix)

=head1 SEE ALSO

L<Gimp>.

=cut

sub TIEHASH {
   my $pkg = shift;
   my $self;

   bless \$self, $pkg;
}

sub FETCH {
   $cfg{$_[1]};
}

tie %Gimp::Config, 'Gimp::Config';

%cfg = (
   IN_GIMP              => q[1],
   libdir               => q[/usr/X11R6/lib],
   gimpplugindir        => q[/usr/X11R6/lib/gimp/1.2],
   INSTALL_PROGRAM      => q[/usr/bin/install -c],
   _PERL                => q[/usr/bin/perl],
   _CPPFLAGS            => q[ -DGTK_DISABLE_COMPAT_H],
   MSGMERGE             => q[@MSGMERGE@],
   _LDFLAGS             => q[-s],
   GIMP                 => q[/usr/X11R6/bin/gimp],
   LIBS                 => q[],
   INC1                 => q[-I/home/users/builder/rpm/BUILD/gimp-1.2.3/plug-ins/perl],
   _GIMP_LIBS           => q[-L/home/users/builder/rpm/BUILD/gimp-1.2.3/plug-ins/perl/../../libgimp/.libs -L/home/users/builder/rpm/BUILD/gimp-1.2.3/plug-ins/perl/../../libgimp -lgimp -L/usr/lib -lglib  -lgimpui],
   _CFLAGS              => q[-O2 -mieee -DPERL_POLLUTE ],
   DEFINE1              => q[ -Ddatadir="\\"/usr/X11R6/share\\"" -DHAVE_PDL=1],
   GIMPTOOL             => q[../../gimptool-1.2],
   pdl_inc              => q[-I/usr/lib/perl5/site_perl/alpha-pld-linux/5.6.1/PDL/Core],
   datadir              => q[/usr/X11R6/share],
   _GIMP_INC_NOUI       => q[-I/home/users/builder/rpm/BUILD/gimp-1.2.3/plug-ins/perl/../.. -I/usr/include/glib-1.2 -I/usr/lib/glib/include -I/usr/X11R6/include/gtk-1.2 -I/usr/include/glib-1.2 -I/usr/lib/glib/include -I/usr/X11R6/include],
   INTLLIBS             => q[],
   exec_prefix          => q[/usr/X11R6],
   bindir               => q[/usr/X11R6/bin],
   pdl_typemaps         => q[/usr/lib/perl5/site_perl/alpha-pld-linux/5.6.1/PDL/Core/typemap.pdl],
   _EXTENSIVE_TESTS     => q[0],
   _GIMP_LIBS_NOUI      => q[-L/home/users/builder/rpm/BUILD/gimp-1.2.3/plug-ins/perl/../../libgimp/.libs -L/home/users/builder/rpm/BUILD/gimp-1.2.3/plug-ins/perl/../../libgimp -lgimp -L/usr/lib -lglib ],
   MSGFMT               => q[/usr/bin/msgfmt],
   _GIMP_INC            => q[-I/home/users/builder/rpm/BUILD/gimp-1.2.3/plug-ins/perl/../.. -I/usr/include/glib-1.2 -I/usr/lib/glib/include -I/usr/X11R6/include/gtk-1.2 -I/usr/include/glib-1.2 -I/usr/lib/glib/include -I/usr/X11R6/include],
   GIMP_PREFIX          => q[/usr/X11R6],
   INSTALL              => q[/usr/bin/install -c],
   GLIB_LIBS            => q[-L/usr/lib -lglib],
   GLIB_CFLAGS          => q[-I/usr/include/glib-1.2 -I/usr/lib/glib/include],
   prefix               => q[/usr/X11R6],
);

1;
